@@ -33,7 +33,6 @@
 import builtins
 from collections import namedtuple
 from collections.abc import Iterator
-from locale import strxfrm as system_strxfrm
 import os
 import re
 import subprocess  # nosec: B404
@@ -74,7 +73,6 @@ from picard.util import (
     normpath,
     pattern_as_regex,
     sort_by_similarity,
-    strxfrm,
     system_supports_long_paths,
     tracknum_and_title_from_filename,
     tracknum_from_filename,
@@ -862,20 +860,6 @@ class WinPrefixLongpathTest(PicardTestCase):
         self.assertEqual(path, win_prefix_longpath(path))
 
 
-class StrxfrmTest(PicardTestCase):
-
-    def test_strxfrm(self):
-        value = 'Motörhead'
-        self.assertEqual(
-            system_strxfrm(value),
-            strxfrm(value)
-        )
-
-    def test_strxfrm_ignore_null_chars(self):
-        result = strxfrm('Foo\0bar\0')
-        self.assertEqual(system_strxfrm('Foobar'), result)
-
-
 class SystemSupportsLongPathsTest(PicardTestCase):
 
     def setUp(self):
